import { checkStrictlyIncreasing, trimPoly, evaluatePolySegment } from "./Utils";
export function createLinearInterpolator(xVals, yVals) {
    var segmentCoeffs = computeLinearPolyCoefficients(xVals, yVals);
    var xValsCopy = Float64Array.from(xVals);
    return function (x) { return evaluatePolySegment(xValsCopy, segmentCoeffs, x); };
}
export function computeLinearPolyCoefficients(xVals, yVals) {
    if (xVals.length != yVals.length) {
        throw new Error("Dimension mismatch.");
    }
    if (xVals.length < 2) {
        throw new Error("Number of points is too small.");
    }
    checkStrictlyIncreasing(xVals);
    var n = xVals.length - 1;
    var segmentCoeffs = new Array(n);
    for (var i = 0; i < n; i++) {
        var dx = xVals[i + 1] - xVals[i];
        var dy = yVals[i + 1] - yVals[i];
        var m = dy / dx;
        var c = new Float64Array(2);
        c[0] = yVals[i];
        c[1] = m;
        segmentCoeffs[i] = trimPoly(c);
    }
    return segmentCoeffs;
}
//# sourceMappingURL=Linear.js.map